@@ -8,11 +8,11 @@ Test::Pod - check for POD errors in files
 
 =head1 VERSION
 
-Version 1.48
+Version 1.49
 
 =cut
 
-our $VERSION = '1.48';
+our $VERSION = '1.49';
 
 =head1 SYNOPSIS
 
@@ -156,8 +156,9 @@ so you can't have already called C<plan>.
 
 If C<@entries> is empty or not passed, the function finds all POD files in
 files in the F<blib> directory if it exists, or the F<lib> directory if not. A
-POD file is one that ends with F<.pod>, F<.pl> and F<.pm>, or any file where
-the first line looks like a shebang line.
+POD file is one that ends with a Perl extension (F<.pod>, F<.pl>, F<.pm>,
+F<.PL>, F<.t>), where the first line looks like a Perl shebang, or a batch
+file (F<.bat>) starting with a line containing C<--*-Perl-*-->.
 
 If you're testing a module, just make a F<t/pod.t>:
 
@@ -216,7 +217,7 @@ sub all_pod_files {
     my @pod;
     require File::Find;
     File::Find::find({
-        wanted   => sub { -f $_ && _is_perl ($_) and push @pod, $File::Find::name },
+        wanted   => sub { -f $_ && _is_perl($_) && push @pod, $File::Find::name },
         no_chdir => 1,
     }, @_ ? @_ : _starting_points());
     return @pod;
@@ -230,48 +231,73 @@ sub _starting_points {
 sub _is_perl {
     my $file = shift;
 
-    return 1 if $file =~ /\.PL$/;
-    return 1 if $file =~ /\.p(?:l|m|od)$/;
-    return 1 if $file =~ /\.t$/;
+    # accept as a Perl file everything that ends with a well known Perl suffix ...
+    return 1 if $file =~ /[.](?:PL|p(?:[lm]|od)|t)$/;
 
     open my $fh, '<', $file or return;
     my $first = <$fh>;
     close $fh;
+    return unless $first;
 
-    return 1 if defined $first && ($first =~ /(?:^#!.*perl)|--\*-Perl-\*--/);
+    # ... or that has a she-bang as first line ...
+    return 1 if $first =~ /^#!.*perl/;
+
+    # ... or that is a .bat ad has a Perl comment line first
+    return 1 if $file =~ /[.]bat$/i && $first =~ /--[*]-Perl-[*]--/;
 
     return;
 }
 
-=head1 TODO
+=head1 SUPPORT
 
-STUFF TO DO
+This module is managed in an open L<GitHub
+repository|http://github.com/perl-pod/test-pod/>. Feel free to fork and
+contribute, or to clone L<git://github.com/perl-pod/test-pod.git> and send
+patches!
 
-Note the changes that are being made.
+Found a bug? Please L<post|http://github.com/perl-pod/test-pod/issues> or
+L<email|mailto:bug-test-pod@rt.cpan.org> a report!
 
-Note that you no longer can test for "no pod".
+=head1 AUTHORS
 
-=head1 AUTHOR
+=over
 
-Currently maintained by David E. Wheeler, C<< <david@justatheory.com> >>.
+=item David E. Wheeler <david@justatheory.com>
 
-Originally by brian d foy.
+Current maintainer.
 
-Maintainer emeritus: Andy Lester, C<< <andy at petdance.com> >>.
+=item Andy Lester C<< <andy at petdance.com> >>
+
+Maintainer emeritus.
+
+=item brian d foy
+
+Orinal author.
+
+=back
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to
-Andy Lester,
-David Wheeler,
-Paul Miller
-and
-Peter Edwards
-for contributions and to C<brian d foy> for the original code.
+Thanks brian d foy for the original code, and to these folks for contributions:
+
+=over
+
+=item * Andy Lester
+
+=item * David E. Wheeler
+
+=item * Paul Miller
+
+=item * Peter Edwards
+
+=item * Luca Ferrari
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010, Andy Lester. Some Rights Reserved.
+Copyright 2006-2010, Andy Lester; 2010-2015 David E. Wheeler. Some Rights
+Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
